@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef TEXTTOSPEECHWIDGET_H
@@ -26,6 +13,10 @@
 namespace KPIMTextEdit {
 class AbstractTextToSpeechInterface;
 class TextToSpeechWidgetPrivate;
+/**
+ * @brief The TextToSpeechWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KPIMTEXTEDIT_EXPORT TextToSpeechWidget : public QWidget
 {
     Q_OBJECT
@@ -38,14 +29,14 @@ public:
         Play,
         Pause
     };
-    Q_ENUMS(State)
+    Q_ENUM(State)
 
-    State state() const;
+    Q_REQUIRED_RESULT State state() const;
     void setState(KPIMTextEdit::TextToSpeechWidget::State state);
 
     void setTextToSpeechInterface(AbstractTextToSpeechInterface *interface);
 
-    bool isReady() const;
+    Q_REQUIRED_RESULT bool isReady() const;
 
 public Q_SLOTS:
     void say(const QString &text);
@@ -57,6 +48,7 @@ Q_SIGNALS:
 
 private:
     void slotVolumeChanged(int value);
+    void slotCloseTextToSpeechWidget();
     void slotConfigure();
     TextToSpeechWidgetPrivate *const d;
 };
